@@ -13,6 +13,12 @@ use zerogc_derive::{unsafe_gc_impl};
 #[cfg(feature = "builtins")]
 use crate::builtins::{AsmSlice, AsmStr};
 
+/// A non-zero pointer type, where optional types
+/// are guaranteed to use the nullable representation
+///
+/// If `T: SimpleNonZeroPointer` -> `sizeof(Option<T>) == sizeof(T) && repr(Option<T>) == repr(T)`
+pub unsafe trait SimpleNonZeroPointer: StaticReflect {}
+
 /// An integer size, named in the style of C/Java
 ///
 /// Although named after their C equivalents,
